@@ -42,7 +42,7 @@ def VacancyAnalysis():
         print(f"Métrica δ = {delta:.4f}, método seleccionado: {method}")
         
         # 2) Condicional
-        if method == 'geometric':
+        if method == 'geometric' and configuracion['geometric_method']:
             # Aplico el método geométrico
             vac_analyzer = WSMet(
                 defect_dump_path=FILE,
